adgtk.tracking
==============

This module is focused on tracking both within an experiment as well as across experiments. 

journal:  focused on user specific items they want tracked within an experiment.
performance: convinient tracking of performance for later reporting.
project: tracks results across multiple experiments
utils: utility functions specific for tracking 